"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_utilities_1 = require("@contentstack/cli-utilities");
const cli_command_1 = require("@contentstack/cli-command");
class GetEarlyAccessHeaderCommand extends cli_command_1.Command {
    async run() {
        try {
            let config = cli_utilities_1.configHandler.get(`earlyAccessHeaders`);
            if (config && Object.keys(config).length > 0) {
                let tableHeaders = Object.keys(config).map((key) => ({
                    ['Alias']: key,
                    ['Early access header']: config[key],
                }));
                cli_utilities_1.cliux.table(tableHeaders, {
                    Alias: {
                        minWidth: 8,
                    },
                    'Early access header': {
                        minWidth: 8,
                    },
                }, {
                    printLine: cli_utilities_1.cliux.print,
                });
            }
            else {
                cli_utilities_1.cliux.print(`No Early Access header found!`, { color: 'red' });
            }
        }
        catch (error) {
            this.log('Unable to retrieve the Early Access header config', error instanceof Error ? error.message : error);
        }
    }
}
exports.default = GetEarlyAccessHeaderCommand;
GetEarlyAccessHeaderCommand.description = 'Display Early Access headers';
GetEarlyAccessHeaderCommand.aliases = ['config:get:ea-header'];
GetEarlyAccessHeaderCommand.examples = ['$ <%= config.bin %> <%= command.id %>'];
