"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_command_1 = require("@contentstack/cli-command");
const cli_utilities_1 = require("@contentstack/cli-utilities");
const utils_1 = require("../../../utils");
class RemoveBranchConfigCommand extends cli_command_1.Command {
    async run() {
        try {
            const { flags: configRemoveFlags } = await this.parse(RemoveBranchConfigCommand);
            if (!configRemoveFlags['stack-api-key']) {
                configRemoveFlags['stack-api-key'] = await utils_1.interactive.askStackAPIKey();
            }
            if (cli_utilities_1.configHandler.get(`baseBranch.${configRemoveFlags['stack-api-key']}`) === undefined) {
                cli_utilities_1.cliux.error(`No config set for stack-api-key : ${configRemoveFlags['stack-api-key']}`);
                return;
            }
            else {
                function deleteConfig() {
                    cli_utilities_1.configHandler.delete(`baseBranch.${configRemoveFlags['stack-api-key']}`);
                    cli_utilities_1.cliux.success(`Base branch configuration for stack-api-key: ${configRemoveFlags['stack-api-key']} removed successfully`);
                }
                cli_utilities_1.cliux.success(`base branch : ${await cli_utilities_1.configHandler.get(`baseBranch.${configRemoveFlags['stack-api-key']}`)}`);
                cli_utilities_1.cliux.success(`stack-api-key: ${configRemoveFlags['stack-api-key']}`);
                if (configRemoveFlags.yes) {
                    deleteConfig();
                }
                else {
                    const confirmation = await utils_1.interactive.askConfirmation();
                    if (!confirmation) {
                        return;
                    }
                    else {
                        deleteConfig();
                    }
                }
            }
        }
        catch (error) {
            cli_utilities_1.cliux.error('error', error);
        }
    }
}
exports.default = RemoveBranchConfigCommand;
RemoveBranchConfigCommand.description = 'Remove branch config for CLI';
RemoveBranchConfigCommand.flags = {
    'stack-api-key': cli_utilities_1.flags.string({ char: 'k', description: 'Stack API Key' }),
    yes: cli_utilities_1.flags.boolean({ char: 'y', description: 'Force Remove' }),
};
RemoveBranchConfigCommand.examples = ['$ csdx config:remove:base-branch', '$ csdx config:remove:base-branch --stack-api-key <value>'];
