"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_utilities_1 = require("@contentstack/cli-utilities");
const utils_1 = require("../../../utils");
const cli_command_1 = require("@contentstack/cli-command");
class RemoveEarlyAccessHeader extends cli_command_1.Command {
    async run() {
        try {
            let { flags: { 'header-alias': earlyAccessHeaderAlias, yes: skipConfirmation }, } = await this.parse(RemoveEarlyAccessHeader);
            if (!earlyAccessHeaderAlias) {
                earlyAccessHeaderAlias = await utils_1.interactive.askEarlyAccessHeaderAlias();
            }
            if (cli_utilities_1.configHandler.get(`earlyAccessHeaders.${earlyAccessHeaderAlias}`) === undefined) {
                cli_utilities_1.cliux.error(`Early Access header not configured for alias: ${earlyAccessHeaderAlias}`);
                return;
            }
            if (!skipConfirmation) {
                const confirmation = await utils_1.interactive.askConfirmation();
                if (!confirmation) {
                    return;
                }
            }
            cli_utilities_1.configHandler.delete(`earlyAccessHeaders.${earlyAccessHeaderAlias}`);
            cli_utilities_1.cliux.success(`Early Access header has been successfully removed`);
        }
        catch (error) {
            this.log('Unable to remove the Early Access header config', error instanceof Error ? error.message : error);
        }
    }
}
exports.default = RemoveEarlyAccessHeader;
RemoveEarlyAccessHeader.description = 'Remove Early Access header';
RemoveEarlyAccessHeader.aliases = ['config:remove:ea-header'];
RemoveEarlyAccessHeader.flags = {
    'header-alias': cli_utilities_1.flags.string({ description: 'Early access header alias' }),
    yes: cli_utilities_1.flags.boolean({ char: 'y', description: 'Force Remove' }),
};
RemoveEarlyAccessHeader.examples = [
    '$ <%= config.bin %> <%= command.id %>',
    '$ <%= config.bin %> <%= command.id %> --header-alias <value>',
];
