"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_utilities_1 = require("@contentstack/cli-utilities");
const utils_1 = require("../../../utils");
const cli_command_1 = require("@contentstack/cli-command");
class SetEarlyAccessHeaderCommand extends cli_command_1.Command {
    async run() {
        var _a, _b;
        try {
            let { flags: { header: earlyAccessHeader, 'header-alias': earlyAccessHeaderAlias }, } = await this.parse(SetEarlyAccessHeaderCommand);
            if (!earlyAccessHeaderAlias) {
                earlyAccessHeaderAlias = (_a = (await utils_1.interactive.askEarlyAccessHeaderAlias())) === null || _a === void 0 ? void 0 : _a.trim();
            }
            if (!earlyAccessHeader) {
                earlyAccessHeader = (_b = (await utils_1.interactive.askEarlyAccessHeaderValue())) === null || _b === void 0 ? void 0 : _b.trim();
            }
            cli_utilities_1.configHandler.set(`earlyAccessHeaders.${earlyAccessHeaderAlias}`, earlyAccessHeader);
            cli_utilities_1.cliux.success(`Early Access header has been successfully set`);
        }
        catch (error) {
            this.log('Unable to set the Early Access header config', error instanceof Error ? error.message : error);
        }
    }
}
exports.default = SetEarlyAccessHeaderCommand;
SetEarlyAccessHeaderCommand.description = 'Set Early Access header';
SetEarlyAccessHeaderCommand.aliases = ['config:set:ea-header'];
SetEarlyAccessHeaderCommand.flags = {
    'header-alias': cli_utilities_1.flags.string({ description: 'Early access header alias' }),
    header: cli_utilities_1.flags.string({ description: 'Early access header value' }),
};
SetEarlyAccessHeaderCommand.examples = [
    '$ <%= config.bin %> <%= command.id %>',
    '$ <%= config.bin %> <%= command.id %> --header <value> --header-alias <value>',
];
